@@ -1,6 +1,6 @@
 /*	$NetBSD: http.c,v 1.40 2016/10/21 11:51:18 jperkin Exp $	*/
 /*-
- * Copyright (c) 2000-2004 Dag-Erling Codan Smrgrav
+ * Copyright (c) 2000-2004 Dag-Erling Coïdan Smørgrav
  * Copyright (c) 2003 Thomas Klausner <wiz@NetBSD.org>
  * Copyright (c) 2008, 2009 Joerg Sonnenberger <joerg@NetBSD.org>
  * All rights reserved.
@@ -82,7 +82,6 @@
 
 #include "fetch.h"
 #include "common.h"
-#include "httperr.h"
 
 /* Maximum number of redirects to follow */
 #define MAX_REDIRECT 5
@@ -480,7 +479,7 @@ http_parse_mtime(const char *p, time_t *mtime)
 	char *locale, *r;
 	struct tm tm;
 
-	locale = strdupa(setlocale(LC_TIME, NULL));
+	locale = strdup(setlocale(LC_TIME, NULL));
 	setlocale(LC_TIME, "C");
 	/* RFC2616 §3.3.1 requires compliant client to accept the Internet
 	 * standard, and the two obsolete, date formats:
@@ -492,6 +491,7 @@ http_parse_mtime(const char *p, time_t *mtime)
 	if (!r) r = strptime(p, "%A, %d-%b-%y %H:%M:%S GMT", &tm);
 	if (!r) r = strptime(p, "%a %b %d %H:%M:%S %Y", &tm);
 	setlocale(LC_TIME, locale);
+	free(locale);
 	if (r == NULL)
 		return (-1);
 	*mtime = timegm(&tm);
@@ -732,13 +732,6 @@ http_connect(struct url *URL, struct url *purl, const char *flags, int *cached)
 		} while (h > hdr_end);
 	}
 	if (is_https && fetch_ssl(conn, URL, verbose) == -1) {
-		/* grrr */
-#ifdef EAUTH
-		errno = EAUTH;
-#else
-		errno = EPERM;
-#endif
-		fetch_syserr();
 		goto ouch;
 	}
 	return (conn);
@@ -814,7 +807,7 @@ set_if_modified_since(conn_t *conn, time_t last_modified)
  * XXX This function is way too long, the do..while loop should be split
  * XXX off into a separate function.
  */
-fetchIO *
+static fetchIO *
 http_request(struct url *URL, const char *op, struct url_stat *us,
     struct url *purl, const char *flags)
 {
@@ -864,14 +857,6 @@ http_request(struct url *URL, const char *op, struct url_stat *us,
 		if (!url->port)
 			url->port = fetch_default_port(url->scheme);
 
-		/* were we redirected to an FTP URL? */
-		if (purl == NULL && strcmp(url->scheme, SCHEME_FTP) == 0) {
-			if (strcmp(op, "GET") == 0)
-				return (ftp_request(url, "RETR", NULL, us, purl, flags));
-			else if (strcmp(op, "HEAD") == 0)
-				return (ftp_request(url, "STAT", NULL, us, purl, flags));
-		}
-
 		/* connect to server or proxy */
 		if ((conn = http_connect(url, purl, flags, &cached)) == NULL)
 			goto ouch;
